import React, { Component } from "react";
import { connect } from "react-redux";
import { Redirect } from "react-router-dom";

import { auth, register } from "../actions/auth";

import { RegisterForm } from "../components/auth/register";
import { AuthForm } from "../components/auth/auth";
import Loader from "../components/HOC/loader";

export class AuthContainer extends Component {
	state = { auth: true };

	toggleAuth = () => this.setState(prevState => ({ auth: !prevState.auth }));

	render() {
		const { auth } = this.state;

		if (this.props.user) {
			return <Redirect to="/" />;
		}

		return (
			<div className="auth">
				<div className="auth__content">
					{auth ? (
						<Loader flag={this.props.isFetching}>
							<AuthForm error={this.props.errorFromAuth} submitHandler={this.props.auth} />
						</Loader>
					) : (
						<Loader flag={this.props.isFetching}>
							<RegisterForm
								submitHandler={this.props.register}
								error={this.props.errorFromAuth}
								successRegister={this.props.successRegister}
							/>
						</Loader>
					)}

					<div className="auth__addintional-content">
						{auth ? (
							<p className="auth__text">
								Do you have account ?{" "}
								<span className="auth__toggle-span" onClick={this.toggleAuth}>
									Sing Up
								</span>
							</p>
						) : (
							<p className="auth__text">
								I have account{" "}
								<span className="auth__toggle-span" onClick={this.toggleAuth}>
									Sign In
								</span>
							</p>
						)}
					</div>
				</div>
			</div>
		);
	}
}

const mapStateToProps = state => ({
	user: state.auth.user,
	isFetching: state.auth.isFetching,
	errorFromAuth: state.auth.error,
	successRegister: state.auth.successRegister
});

export default connect(
	mapStateToProps,
	{ auth, register }
)(AuthContainer);
